# Orphan Page

This page is not listed in the 'nav' section of 'mkdocs.yml'. The plugin should automatically discover it and create it in Confluence under the root parent page, preserving the 'orphans/' directory structure.
